@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-07-28'; # DATE
-our $VERSION = '1.24'; # VERSION
+our $DATE = '2015-08-09'; # DATE
+our $VERSION = '1.25'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1340,7 +1340,17 @@ sub run {
     if ($self->skip_format ||
             $r->{meta}{'cmdline.skip_format'} ||
             $r->{res}[3]{'cmdline.skip_format'}) {
-        $r->{fres} = $r->{res}[2];
+        # skip formatting, just print whatever is in res[2] (with a bit of
+        # exception)
+        if (!($r->{res}[0] =~ /\A2/ || $r->{res}[0] == 304) &&
+                !defined($r->{res}[2])) {
+            # [ux] if there is an error and no result, we still show the error
+            # message from res[0] & res[1]. otherwise, user might be confused
+            # because there is no error message
+            $r->{fres} = "ERROR $r->{res}[0]: $r->{res}[1]";
+        } else {
+            $r->{fres} = $r->{res}[2] // '';
+        }
     } elsif ($r->{res}[3]{stream} // $r->{meta}{result}{stream}) {
         # stream will be formatted as displayed by display_result()
     } else {
@@ -1389,7 +1399,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.24 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-07-28.
+This document describes version 1.25 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-08-09.
 
 =head1 DESCRIPTION
 
@@ -2289,7 +2299,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
